@@ -2,9 +2,9 @@
 # LICENSE: CC BY-NC 4.0
 
 import glob
-import logging
 import os
 
+from loguru import logger
 from pottery import Redlock
 import pynetbox
 import yaml
@@ -23,7 +23,7 @@ def load_data_from_filesystem(collection=None, device=None, state=None):
 
     data = {}
     if not device:
-        logging.info(f"Loading collection {collection}")
+        logger.info(f"Loading collection {collection}")
 
         if os.path.isfile("/netbox/{CONF.collection}/{CONF.state}.yaml"):
             with open(f"/netbox/{collection}/{state}.yaml") as fp:
@@ -36,11 +36,15 @@ def load_data_from_filesystem(collection=None, device=None, state=None):
             data = {**data_a, **data}
 
     elif device and collection:
-        if not os.path.isfile("/netbox/{CONF.collection}/{CONF.device}/{CONF.state}.yaml"):
-            logging.error(f"State {state} for device {device} in collection {collection} is not available")
+        if not os.path.isfile(
+            "/netbox/{CONF.collection}/{CONF.device}/{CONF.state}.yaml"
+        ):
+            logger.error(
+                f"State {state} for device {device} in collection {collection} is not available"
+            )
             return data
 
-        logging.info(f"Loading device {device} from collection {collection}")
+        logger.info(f"Loading device {device} from collection {collection}")
 
         with open(f"/netbox/{collection}/{device}/{state}.yaml") as fp:
             data = yaml.load(fp, Loader=yaml.SafeLoader)
@@ -50,19 +54,19 @@ def load_data_from_filesystem(collection=None, device=None, state=None):
         # A device can be in exactly one collection
         result = [x[0] for x in os.walk("/netbox") if device in x[0]]
         if result:
-            logging.info(f"Loading device {device}")
+            logger.info(f"Loading device {device}")
 
             try:
                 with open(f"{result[0]}/{state}.yaml") as fp:
                     data = yaml.load(fp, Loader=yaml.SafeLoader)
             except:  # noqa
-                logging.error(f"State {state} for device {device} is not available")
+                logger.error(f"State {state} for device {device} is not available")
                 return data
         else:
-            logging.error(f"Device {device} is not defined in any collection")
+            logger.error(f"Device {device} is not defined in any collection")
 
     else:
-        logging.error("Specify at least a collection or a device")
+        logger.error("Specify at least a collection or a device")
 
     return data
 
@@ -129,13 +133,18 @@ def manage_interfaces(device, data):
         device_b = utils.nb.dcim.devices.get(name=device_target)
 
         interface_a = utils.nb.dcim.interfaces.get(name=interface, device=device)
-        interface_b = utils.nb.dcim.interfaces.get(name=data[device][interface]["interface"], device=data[device][interface]["device"])
+        interface_b = utils.nb.dcim.interfaces.get(
+            name=data[device][interface]["interface"],
+            device=data[device][interface]["device"],
+        )
 
         if not interface_a:
-            logging.error(f"{device} # {interface} --> not found")
+            logger.error(f"{device} # {interface} --> not found")
 
         if not interface_b:
-            logging.error(f"{data[device][interface]['device']} # {data[device][interface]['interface']} --> not found")
+            logger.error(
+                f"{data[device][interface]['device']} # {data[device][interface]['interface']} --> not found"
+            )
 
         # Ignore interfaces without an mac address
         try:
@@ -160,21 +169,23 @@ def manage_interfaces(device, data):
                 address_a = utils.nb.ipam.ip_addresses.get(address=address)
                 if type(address) == str:
                     address_a = utils.nb.ipam.ip_addresses.get(address=address)
-                    logging.info(f"Address {address} -> {interface}")
+                    logger.info(f"Address {address} -> {interface}")
                     if not address_a:
                         utils.nb.ipam.ip_addresses.create(
                             address=address,
                             assigned_object_type="dcim.interface",
-                            assigned_object_id=interface_a.id
+                            assigned_object_id=interface_a.id,
                         )
                 else:
-                    address_a = utils.nb.ipam.ip_addresses.get(address=address["address"])
-                    logging.info(f"Address {address['address']} -> {interface}")
+                    address_a = utils.nb.ipam.ip_addresses.get(
+                        address=address["address"]
+                    )
+                    logger.info(f"Address {address['address']} -> {interface}")
                     if not address_a:
                         address_a = utils.nb.ipam.ip_addresses.create(
                             assigned_object_type="dcim.interface",
                             assigned_object_id=interface_a.id,
-                            **address
+                            **address,
                         )
                     if "primary" in address and bool(address["primary"]):
                         primary_address = address_a.id
@@ -182,26 +193,38 @@ def manage_interfaces(device, data):
                         device_a.save()
 
         # Remove addresses from the interface that have been removed
-        for address in utils.nb.ipam.ip_addresses.filter(device=device, interface=interface):
+        for address in utils.nb.ipam.ip_addresses.filter(
+            device=device, interface=interface
+        ):
             delete = True
             if "addresses" in data[device][interface]:
                 for address_a in data[device][interface]["addresses"]:
                     if type(address_a) == str and address_a == str(address):
                         delete = False
-                    elif "address" in address_a and address_a["address"] == str(address):
+                    elif "address" in address_a and address_a["address"] == str(
+                        address
+                    ):
                         delete = False
 
             if delete:
                 address.delete()
 
-        logging.info(f"{interface_a} -> {device_target} # {interface_b}")
+        logger.info(f"{interface_a} -> {device_target} # {interface_b}")
 
+        if interface_a.label:
+            port_a = interface_a.label
         # EthernetXX/Y
-        if "Ethernet" in interface_a.name:
+        elif "Ethernet" in interface_a.name and "/" in interface_a.name:
             port_a = interface_a.name[8:].split("/")[0]
+        # EthernetXX
+        elif "Ethernet" in interface_a.name:
+            port_a = interface_a.name[8:]
         # etherXX
         elif "ether" in interface_a.name:
             port_a = interface_a.name[5:]
+        # ethXX
+        elif "eth" in interface_a.name:
+            port_a = interface_a.name[3:]
         # sfp-sfpplusXX
         elif "sfp-sfpplus" in interface_a.name:
             port_a = interface_a.name[11:]
@@ -214,12 +237,20 @@ def manage_interfaces(device, data):
         else:
             port_a = interface_a.name
 
+        if interface_b.label:
+            port_b = interface_b.label
         # EthernetXX/Y
-        if "Ethernet" in interface_b.name:
+        elif "Ethernet" in interface_b.name and "/" in interface_b.name:
             port_b = interface_b.name[8:].split("/")[0]
+        # EthernetXX
+        elif "Ethernet" in interface_b.name:
+            port_b = interface_b.name[8:]
         # etherXX
         elif "ether" in interface_b.name:
             port_b = interface_b.name[5:]
+        # ethXX
+        elif "eth" in interface_b.name:
+            port_b = interface_b.name[3:]
         # sfp-sfpplusXX
         elif "sfp-sfpplus" in interface_b.name:
             port_b = interface_b.name[11:]
@@ -232,51 +263,40 @@ def manage_interfaces(device, data):
         else:
             port_b = interface_b.name
 
-        near_end_a = f"{device_a.position}:{port_a}"
+        position_a = int(device_a.position)
+        position_b = int(device_b.position)
+
+        near_end_a = f"{position_a}:{port_a}"
         if device_a.rack.name == device_b.rack.name:
-            far_end_a = f"{device_b.position}:{port_b}"
+            far_end_a = f"{position_b}:{port_b}"
         else:
-            far_end_a = f"{device_b.rack.name}-{device_b.position}:{port_b}"
+            far_end_a = f"{device_b.rack.name}-{position_b}:{port_b}"
         label_a = f"{near_end_a} / {far_end_a}"
 
-        near_end_b = f"{device_b.position}:{port_b}"
+        near_end_b = f"{position_b}:{port_b}"
         if device_b.rack.name == device_a.rack.name:
-            far_end_b = f"{device_a.position}:{port_a}"
+            far_end_b = f"{position_a}:{port_a}"
         else:
-            far_end_b = f"{device_a.rack.name}-{device_a.position}:{port_a}"
+            far_end_b = f"{device_a.rack.name}-{position_a}:{port_a}"
         label_b = f"{near_end_b} / {far_end_b}"
 
-        interface_a.update({"label": label_a})
-        interface_b.update({"label": label_b})
+        interface_a.update({"description": label_a})
+        interface_b.update({"description": label_b})
 
-        connection = utils.nb.dcim.cables.get(
-            termination_a_type="dcim.interface",
-            termination_b_type="dcim.interface",
-            termination_a_id=interface_a.id,
-            termination_b_id=interface_b.id
-        )
+        termination_a = {"object_type": "dcim.interface", "object_id": interface_a.id}
+        termination_b = {"object_type": "dcim.interface", "object_id": interface_b.id}
 
-        # NOTE: also check the other direction
-        if not connection:
-            connection = utils.nb.dcim.cables.get(
-                termination_a_type="dcim.interface",
-                termination_b_type="dcim.interface",
-                termination_a_id=interface_b.id,
-                termination_b_id=interface_a.id
+        try:
+            connection = utils.nb.dcim.cables.create(
+                a_terminations=[termination_a],
+                b_terminations=[termination_b],
+                type=data[device][interface]["type"],
             )
-
-        if not connection:
-            try:
-                connection = utils.nb.dcim.cables.create(
-                    termination_a_type="dcim.interface",
-                    termination_b_type="dcim.interface",
-                    termination_a_id=interface_a.id,
-                    termination_b_id=interface_b.id,
-                    type=data[device][interface]["type"]
-                )
-            except pynetbox.core.query.RequestError as e:
-                logging.error(f"ERROR --> {e}")
-                pass
+        except pynetbox.core.query.RequestError as e:
+            # The "Duplicate termination found" error can be ignored
+            if "Duplicate termination found" not in e.error:
+                logger.error(f"ERROR --> {e.error}")
+            pass
 
         # ensure that all interfaces are enabled that should be enabled
         if not interface_a.enabled:
@@ -287,22 +307,25 @@ def manage_interfaces(device, data):
                 interface_a.enabled = True
 
             if interface_a.enabled:
-                logging.info(f"{device_a} # {interface_a} --> enabled")
+                logger.info(f"{device_a} # {interface_a} --> enabled")
             else:
-                logging.info(f"{device_a} # {interface_a} --> disabled")
+                logger.info(f"{device_a} # {interface_a} --> disabled")
 
             interface_a.save()
 
         if not interface_b.enabled:
-            if "data" in data[device][interface] and "enabled" in data[device][interface]["data"]:
+            if (
+                "data" in data[device][interface]
+                and "enabled" in data[device][interface]["data"]
+            ):
                 interface_b.enabled = bool(data[device][interface]["data"]["enabled"])
             else:
                 interface_b.enabled = True
 
             if interface_b.enabled:
-                logging.info(f"{device_b} # {interface_b} --> enabled")
+                logger.info(f"{device_b} # {interface_b} --> enabled")
             else:
-                logging.info(f"{device_b} # {interface_b} --> disabled")
+                logger.info(f"{device_b} # {interface_b} --> disabled")
 
             interface_b.save()
 
@@ -314,39 +337,41 @@ def manage_interfaces(device, data):
                 vlan_a = utils.nb.ipam.vlans.get(vid=vlan)
                 if not vlan_a:
                     try:
-                        vlan_a = utils.nb.ipam.vlans.create(name=f"VLAN {vlan}", vid=vlan)
+                        vlan_a = utils.nb.ipam.vlans.create(
+                            name=f"VLAN {vlan}", vid=vlan
+                        )
                     except pynetbox.core.query.RequestError as e:
-                        logging.error(f"ERROR --> {e}")
+                        logger.error(f"ERROR --> {e}")
                         pass
 
                 if data[device][interface]["vlans"][vlan] == "untagged":
-                    logging.info(f"Untagged VLAN {vlan_a.vid} -> {interface_a.name}")
+                    logger.info(f"Untagged VLAN {vlan_a.vid} -> {interface_a.name}")
                     interface_a.untagged_vlan = vlan_a.id
 
                     if interface_a.name not in lag_interfaces[device]:
-                        logging.info(f"Tagged VLAN {vlan_a.vid} -> {interface_b.name}")
+                        logger.info(f"Tagged VLAN {vlan_a.vid} -> {interface_b.name}")
                         interface_b.untagged_vlan = vlan_a.id
 
                 elif vlan_a.id not in interface_a.tagged_vlans:
-                    logging.info(f"Tagged VLAN {vlan_a.vid} -> {interface_a.name}")
+                    logger.info(f"Tagged VLAN {vlan_a.vid} -> {interface_a.name}")
                     interface_a.tagged_vlans.append(vlan_a.id)
 
                     if interface_a.name not in lag_interfaces[device]:
-                        logging.info(f"Tagged VLAN {vlan_a.vid} -> {interface_b.name}")
+                        logger.info(f"Tagged VLAN {vlan_a.vid} -> {interface_b.name}")
                         interface_b.tagged_vlans.append(vlan_a.id)
 
                     tagged = True
 
             if tagged:
-                interface_a.mode = 'tagged'
+                interface_a.mode = "tagged"
 
                 if interface_a.name not in lag_interfaces[device]:
-                    interface_b.mode = 'tagged'
+                    interface_b.mode = "tagged"
             else:
-                interface_a.mode = 'access'
+                interface_a.mode = "access"
 
                 if interface_a.name not in lag_interfaces[device]:
-                    interface_b.mode = 'access'
+                    interface_b.mode = "access"
 
             interface_a.save()
 
@@ -364,22 +389,28 @@ def manage_port_channels(device, data):
 
     for interface in data[device]:
         if data[device][interface]["type"] == "port-channel":
-            logging.info(f"Local port channel {device} # {interface} -> {data[device][interface]['interfaces']}")
+            logger.info(
+                f"Local port channel {device} # {interface} -> {data[device][interface]['interfaces']}"
+            )
             device_a = utils.nb.dcim.devices.get(name=device)
 
             # Create the local port channel
             port_channel_a = utils.nb.dcim.interfaces.get(name=interface, device=device)
             if not port_channel_a:
                 try:
-                    port_channel_a = utils.nb.dcim.interfaces.create(name=interface, device=device_a.id, type="lag")
+                    port_channel_a = utils.nb.dcim.interfaces.create(
+                        name=interface, device=device_a.id, type="lag"
+                    )
                 except pynetbox.core.query.RequestError as e:
-                    logging.error(f"ERROR --> {e}")
+                    logger.error(f"ERROR --> {e}")
                     pass
 
             # Create the remote port channels and add the local interfaces to the local port channel
             remote_port_channels = []
             for interface_x in data[device][interface]["interfaces"]:
-                interface_a = utils.nb.dcim.interfaces.get(name=interface_x, device=device)
+                interface_a = utils.nb.dcim.interfaces.get(
+                    name=interface_x, device=device
+                )
 
                 # NOTE: The VLANs on the Ethernet interfaces on the local devices are preserved for
                 #       visibility in the Netbox.
@@ -389,20 +420,33 @@ def manage_port_channels(device, data):
                 interface_a.lag = port_channel_a
                 interface_a.save()
 
-                port_channel_b_name = f"Port-Channel{data[device][interface]['channel']}"
-                interface_b = utils.nb.dcim.interfaces.get(name=interface_a.connected_endpoint.name, device=interface_a.connected_endpoint.device)
+                port_channel_b_name = (
+                    f"Port-Channel{data[device][interface]['channel']}"
+                )
+                interface_b = utils.nb.dcim.interfaces.get(
+                    name=interface_a.connected_endpoint.name,
+                    device=interface_a.connected_endpoint.device,
+                )
 
                 interface_b.untagged_vlan = None
                 interface_b.tagged_vlans = []
 
-                logging.info(f"Remote port channel {interface_b.device.name} # {port_channel_b_name} -> {interface_b.device.name} # {interface_b.name} ({interface_a.name})")
+                logger.info(
+                    f"Remote port channel {interface_b.device.name} # {port_channel_b_name} -> {interface_b.device.name} # {interface_b.name} ({interface_a.name})"
+                )
 
-                port_channel_b = utils.nb.dcim.interfaces.get(name=port_channel_b_name, device=interface_b.device)
+                port_channel_b = utils.nb.dcim.interfaces.get(
+                    name=port_channel_b_name, device=interface_b.device
+                )
                 if not port_channel_b:
                     try:
-                        port_channel_b = utils.nb.dcim.interfaces.create(name=port_channel_b_name, device=interface_b.device.id, type="lag")
+                        port_channel_b = utils.nb.dcim.interfaces.create(
+                            name=port_channel_b_name,
+                            device=interface_b.device.id,
+                            type="lag",
+                        )
                     except pynetbox.core.query.RequestError as e:
-                        logging.error(f"ERROR --> {e}")
+                        logger.error(f"ERROR --> {e}")
                         pass
 
                 interface_b.lag = port_channel_b
@@ -416,34 +460,40 @@ def manage_port_channels(device, data):
                     address_a = utils.nb.ipam.ip_addresses.get(address=address)
                     if type(address) == str:
                         address_a = utils.nb.ipam.ip_addresses.get(address=address)
-                        logging.info(f"Address {address} -> {interface}")
+                        logger.info(f"Address {address} -> {interface}")
                         if not address_a:
                             utils.nb.ipam.ip_addresses.create(
                                 address=address,
                                 assigned_object_type="dcim.interface",
-                                assigned_object_id=port_channel_a.id
+                                assigned_object_id=port_channel_a.id,
                             )
                     else:
-                        address_a = utils.nb.ipam.ip_addresses.get(address=address["address"])
-                        logging.info(f"Address {address['address']} -> {interface}")
+                        address_a = utils.nb.ipam.ip_addresses.get(
+                            address=address["address"]
+                        )
+                        logger.info(f"Address {address['address']} -> {interface}")
                         if not address_a:
                             address_a = utils.nb.ipam.ip_addresses.create(
                                 assigned_object_type="dcim.interface",
                                 assigned_object_id=port_channel_a.id,
-                                **address
+                                **address,
                             )
                         if "primary" in address and bool(address["primary"]):
                             device_a.primary_ip4 = address_a.id
                             device_a.save()
 
             # Remove addresses from the local port channel that have been removed
-            for address in utils.nb.ipam.ip_addresses.filter(device=device, interface=interface):
+            for address in utils.nb.ipam.ip_addresses.filter(
+                device=device, interface=interface
+            ):
                 delete = True
                 if "addresses" in data[device][interface]:
                     for address_a in data[device][interface]["addresses"]:
                         if type(address_a) == str and address_a == str(address):
                             delete = False
-                        elif "address" in address_a and address_a["address"] == str(address):
+                        elif "address" in address_a and address_a["address"] == str(
+                            address
+                        ):
                             delete = False
 
                 if delete:
@@ -461,37 +511,47 @@ def manage_port_channels(device, data):
                     vlan_a = utils.nb.ipam.vlans.get(vid=vlan)
                     if not vlan_a:
                         try:
-                            vlan_a = utils.nb.ipam.vlans.create(name=f"VLAN {vlan}", vid=vlan)
+                            vlan_a = utils.nb.ipam.vlans.create(
+                                name=f"VLAN {vlan}", vid=vlan
+                            )
                         except pynetbox.core.query.RequestError as e:
-                            logging.error(f"ERROR --> {e}")
+                            logger.error(f"ERROR --> {e}")
                             pass
 
                     if data[device][interface]["vlans"][vlan] == "untagged":
-                        logging.info(f"Untagged VLAN {vlan_a.vid} -> {port_channel_a.name}")
+                        logger.info(
+                            f"Untagged VLAN {vlan_a.vid} -> {port_channel_a.name}"
+                        )
                         port_channel_a.untagged_vlan = vlan_a.id
 
                         for port_channel_b in remote_port_channels:
-                            logging.info(f"Untagged VLAN {vlan_a.vid} -> {port_channel_b.name}")
+                            logger.info(
+                                f"Untagged VLAN {vlan_a.vid} -> {port_channel_b.name}"
+                            )
                             port_channel_b.untagged_vlan = vlan_a.id
                     elif vlan_a.id not in port_channel_a.tagged_vlans:
-                        logging.info(f"Tagged VLAN {vlan_a.vid} -> {port_channel_a.name}")
+                        logger.info(
+                            f"Tagged VLAN {vlan_a.vid} -> {port_channel_a.name}"
+                        )
                         port_channel_a.tagged_vlans.append(vlan_a.id)
                         tagged = True
 
                         for port_channel_b in remote_port_channels:
-                            logging.info(f"Tagged VLAN {vlan_a.vid} -> {port_channel_b.name}")
+                            logger.info(
+                                f"Tagged VLAN {vlan_a.vid} -> {port_channel_b.name}"
+                            )
                             port_channel_b.tagged_vlans.append(vlan_a.id)
 
                 if tagged:
-                    port_channel_a.mode = 'tagged'
+                    port_channel_a.mode = "tagged"
 
                     for port_channel_b in remote_port_channels:
-                        port_channel_b.mode = 'tagged'
+                        port_channel_b.mode = "tagged"
                 else:
-                    port_channel_a.mode = 'access'
+                    port_channel_a.mode = "access"
 
                     for port_channel_b in remote_port_channels:
-                        port_channel_b.mode = 'access'
+                        port_channel_b.mode = "access"
 
             port_channel_a.save()
             port_channel_b.save()
@@ -503,7 +563,10 @@ def remove_port_channels(device, data):
     for interface in utils.nb.dcim.interfaces.filter(device=device, type="lag"):
         delete = True
         for interface_a in data[device]:
-            if data[device][interface_a]["type"] == "port-channel" and str(interface) == interface_a:
+            if (
+                data[device][interface_a]["type"] == "port-channel"
+                and str(interface) == interface_a
+            ):
                 delete = False
 
         if delete and "Port-Channel" not in interface.name:
@@ -518,16 +581,21 @@ def manage_virtual_interfaces(device, data):
 
     for interface in data[device]:
         if data[device][interface]["type"] == "virtual":
-            logging.info(f"Virtual interface {interface} for {device}")
+            logger.info(f"Virtual interface {interface} for {device}")
 
             device_a = utils.nb.dcim.devices.get(name=device)
 
             interface_a = utils.nb.dcim.interfaces.get(name=interface, device=device)
             if not interface_a:
                 try:
-                    interface_a = utils.nb.dcim.interfaces.create(name=interface, device=device_a.id, type="virtual", **data[device][interface]["data"])
+                    interface_a = utils.nb.dcim.interfaces.create(
+                        name=interface,
+                        device=device_a.id,
+                        type="virtual",
+                        **data[device][interface]["data"],
+                    )
                 except pynetbox.core.query.RequestError as e:
-                    logging.error(f"ERROR --> {e}")
+                    logger.error(f"ERROR --> {e}")
                     pass
 
             if "addresses" in data[device][interface]:
@@ -535,34 +603,40 @@ def manage_virtual_interfaces(device, data):
                     address_a = utils.nb.ipam.ip_addresses.get(address=address)
                     if type(address) == str:
                         address_a = utils.nb.ipam.ip_addresses.get(address=address)
-                        logging.info(f"Address {address} -> {interface}")
+                        logger.info(f"Address {address} -> {interface}")
                         if not address_a:
                             utils.nb.ipam.ip_addresses.create(
                                 address=address,
                                 assigned_object_type="dcim.interface",
-                                assigned_object_id=interface_a.id
+                                assigned_object_id=interface_a.id,
                             )
                     else:
-                        address_a = utils.nb.ipam.ip_addresses.get(address=address["address"])
-                        logging.info(f"Address {address['address']} -> {interface}")
+                        address_a = utils.nb.ipam.ip_addresses.get(
+                            address=address["address"]
+                        )
+                        logger.info(f"Address {address['address']} -> {interface}")
                         if not address_a:
                             address_a = utils.nb.ipam.ip_addresses.create(
                                 assigned_object_type="dcim.interface",
                                 assigned_object_id=interface_a.id,
-                                **address
+                                **address,
                             )
                         if "primary" in address and bool(address["primary"]):
                             device_a.primary_ip4 = address_a.id
                             device_a.save()
 
             # Remove addresses from the interface that have been removed
-            for address in utils.nb.ipam.ip_addresses.filter(device=device, interface=interface):
+            for address in utils.nb.ipam.ip_addresses.filter(
+                device=device, interface=interface
+            ):
                 delete = True
                 if "addresses" in data[device][interface]:
                     for address_a in data[device][interface]["addresses"]:
                         if type(address_a) == str and address_a == str(address):
                             delete = False
-                        elif "address" in address_a and address_a["address"] == str(address):
+                        elif "address" in address_a and address_a["address"] == str(
+                            address
+                        ):
                             delete = False
 
                 if delete:
@@ -576,9 +650,11 @@ def manage_virtual_interfaces(device, data):
                     vlan_a = utils.nb.ipam.vlans.get(vid=vlan)
                     if not vlan_a:
                         try:
-                            vlan_a = utils.nb.ipam.vlans.create(name=f"VLAN {vlan}", vid=vlan)
+                            vlan_a = utils.nb.ipam.vlans.create(
+                                name=f"VLAN {vlan}", vid=vlan
+                            )
                         except pynetbox.core.query.RequestError as e:
-                            logging.error(f"ERROR --> {e}")
+                            logger.error(f"ERROR --> {e}")
                             pass
 
                     if data[device][interface]["vlans"][vlan] == "untagged":
@@ -588,9 +664,9 @@ def manage_virtual_interfaces(device, data):
                         tagged = True
 
                 if tagged:
-                    interface_a.mode = 'tagged'
+                    interface_a.mode = "tagged"
                 else:
-                    interface_a.mode = 'access'
+                    interface_a.mode = "access"
                 interface_a.save()
 
 
@@ -600,7 +676,10 @@ def remove_virtual_interfaces(device, data):
     for interface in utils.nb.dcim.interfaces.filter(device=device, type="virtual"):
         delete = True
         for interface_a in data[device]:
-            if data[device][interface_a]["type"] == "virtual" and str(interface) == interface_a:
+            if (
+                data[device][interface_a]["type"] == "virtual"
+                and str(interface) == interface_a
+            ):
                 delete = False
 
         if delete:
@@ -615,54 +694,66 @@ def manage_mlag_devices(device, data):
             data_a = data[device][interface]["data"]
             device_a = utils.nb.dcim.devices.get(name=device)
 
-            logging.info(f"Local port channel {device} # Port-Channel{data_a['channel']}")
+            logger.info(
+                f"Local port channel {device} # Port-Channel{data_a['channel']}"
+            )
 
-            port_channel_a = utils.nb.dcim.interfaces.get(name=f"Port-Channel{data_a['channel']}", device=device)
+            port_channel_a = utils.nb.dcim.interfaces.get(
+                name=f"Port-Channel{data_a['channel']}", device=device
+            )
             if not port_channel_a:
                 try:
-                    port_channel_a = utils.nb.dcim.interfaces.create(name=f"Port-Channel{data_a['channel']}", device=device_a.id, type="lag")
+                    port_channel_a = utils.nb.dcim.interfaces.create(
+                        name=f"Port-Channel{data_a['channel']}",
+                        device=device_a.id,
+                        type="lag",
+                    )
                 except pynetbox.core.query.RequestError as e:
-                    logging.error(f"ERROR --> {e}")
+                    logger.error(f"ERROR --> {e}")
                     pass
 
             for interface_x in data[device][interface]["interfaces"]:
-                interface_a = utils.nb.dcim.interfaces.get(name=interface_x, device=device)
+                interface_a = utils.nb.dcim.interfaces.get(
+                    name=interface_x, device=device
+                )
                 interface_a.lag = port_channel_a
                 interface_a.save()
 
-            logging.info(f"Virtual interface {data_a['vlan']} for {device}")
-            interface_a = utils.nb.dcim.interfaces.get(name=f"Vlan{data_a['vlan']}", device=device)
+            logger.info(f"Virtual interface {data_a['vlan']} for {device}")
+            interface_a = utils.nb.dcim.interfaces.get(
+                name=f"Vlan{data_a['vlan']}", device=device
+            )
             if not interface_a:
                 try:
-                    interface_a = utils.nb.dcim.interfaces.create(name=f"Vlan{data_a['vlan']}", device=device_a.id, type="virtual")
+                    interface_a = utils.nb.dcim.interfaces.create(
+                        name=f"Vlan{data_a['vlan']}", device=device_a.id, type="virtual"
+                    )
                 except pynetbox.core.query.RequestError as e:
-                    logging.error(f"ERROR --> {e}")
+                    logger.error(f"ERROR --> {e}")
                     pass
 
-            vlan_a = utils.nb.ipam.vlans.get(vid=data_a['vlan'])
+            vlan_a = utils.nb.ipam.vlans.get(vid=data_a["vlan"])
             interface_a.untagged_vlan = vlan_a
             interface_a.parent = port_channel_a
             interface_a.save()
 
-            # logging.info(f"Address {data_a['address']} -> {interface_a.name}")
+            # logger.info(f"Address {data_a['address']} -> {interface_a.name}")
             address_a = utils.nb.ipam.ip_addresses.get(address=data_a["address"])
             if not address_a:
                 utils.nb.ipam.ip_addresses.create(
                     address=data_a["address"],
                     assigned_object_type="dcim.interface",
-                    assigned_object_id=interface_a.id
+                    assigned_object_id=interface_a.id,
                 )
 
 
 def set_maintenance(device, state):
     """Set the maintenance state for a device in the Netbox."""
 
-    logging.info(f"Set maintenance state of device {device} = {state}")
+    logger.info(f"Set maintenance state of device {device} = {state}")
 
     device_a = utils.nb.dcim.devices.get(name=device)
-    device_a.custom_fields = {
-        "maintenance": state
-    }
+    device_a.custom_fields = {"maintenance": state}
     device_a.save()
 
 
@@ -691,84 +782,70 @@ def set_state(device, state, state_type):
 def set_provision_state(device, state):
     """Set the provision state (provision_state) for a device in the Netbox."""
 
-    logging.info(f"Set provision state of device {device} = {state}")
+    logger.info(f"Set provision state of device {device} = {state}")
 
     device_a = utils.nb.dcim.devices.get(name=device)
-    device_a.custom_fields = {
-        "provision_state": state
-    }
+    device_a.custom_fields = {"provision_state": state}
     device_a.save()
 
 
 def set_ironic_state(device, state):
     """Set the ironic state (ironic_state) for a device in the Netbox."""
 
-    logging.info(f"Set ironic state of device {device} = {state}")
+    logger.info(f"Set ironic state of device {device} = {state}")
 
     device_a = utils.nb.dcim.devices.get(name=device)
-    device_a.custom_fields = {
-        "ironic_state": state
-    }
+    device_a.custom_fields = {"ironic_state": state}
     device_a.save()
 
 
 def set_introspection_state(device, state):
     """Set the introspection state (introspection_state) for a device in the Netbox."""
 
-    logging.info(f"Set introspection state of device {device} = {state}")
+    logger.info(f"Set introspection state of device {device} = {state}")
 
     device_a = utils.nb.dcim.devices.get(name=device)
-    device_a.custom_fields = {
-        "introspection_state": state
-    }
+    device_a.custom_fields = {"introspection_state": state}
     device_a.save()
 
 
 def set_deployment_state(device, state):
     """Set the deployment state (deployment_state) for a device in the Netbox."""
 
-    logging.info(f"Set deployment state of device {device} = {state}")
+    logger.info(f"Set deployment state of device {device} = {state}")
 
     device_a = utils.nb.dcim.devices.get(name=device)
-    device_a.custom_fields = {
-        "deployment_state": state
-    }
+    device_a.custom_fields = {"deployment_state": state}
     device_a.save()
 
 
 def set_power_state(device, state):
     """Set the power state (power_state) for a device in the Netbox."""
 
-    logging.info(f"Set power state of device {device} = {state}")
+    logger.info(f"Set power state of device {device} = {state}")
 
     device_a = utils.nb.dcim.devices.get(name=device)
-    device_a.custom_fields = {
-        "power_state": state
-    }
+    device_a.custom_fields = {"power_state": state}
     device_a.save()
 
 
 def set_device_state(device, state):
     """Set the state (device_state) for a device in the Netbox."""
 
-    logging.info(f"Set state of device {device} = {state}")
+    logger.info(f"Set state of device {device} = {state}")
 
     device_a = utils.nb.dcim.devices.get(name=device)
-    device_a.custom_fields = {
-        "device_state": state
-    }
+    device_a.custom_fields = {"device_state": state}
     device_a.save()
 
 
 def set_device_transition(device, transition):
     """Set the transition (device_transition) for a device in the Netbox."""
 
-    logging.info(f"Set transition of device {device} = {transition}")
+    logger.info(f"Set transition of device {device} = {transition}")
 
     device_a = utils.nb.dcim.devices.get(name=device)
-    device_a.custom_fields = {
-        "device_transition": transition
-    }
+    device_a.custom_fields = {"device_transition": transition}
     device_a.save()
 
 
@@ -818,7 +895,7 @@ def run(device, state=None, data={}, enforce=False):
 
     # Device is already in the target state, no transition necessary
     if not enforce and current_state == state:
-        logging.info(f"Device {device} is already in state {state}")
+        logger.info(f"Device {device} is already in state {state}")
         return
 
     transitions = get_transitions(data.keys())
@@ -831,12 +908,15 @@ def run(device, state=None, data={}, enforce=False):
 
     # One transition is already running, no second transition possible
     if not enforce and current_transition and current_transition != "0":
-        logging.info(f"{device} is already in transit")
+        logger.info(f"{device} is already in transit")
         return
 
     # Get connected devices in source and target state
-    connected_devices = set(get_connected_devices(device, current_data) + get_connected_devices(device, data))
-    logging.info(connected_devices)
+    connected_devices = set(
+        get_connected_devices(device, current_data)
+        + get_connected_devices(device, data)
+    )
+    logger.info(connected_devices)
 
     # Allow only one active transition per device
     lock = Redlock(key=f"lock_{device}", masters={utils.redis}, auto_release_time=120)
