@@ -2,7 +2,7 @@ from celery import Celery
 
 from osism.tasks import Config, run_ansible_in_environment
 
-app = Celery('kolla')
+app = Celery("kolla")
 app.config_from_object(Config)
 
 
@@ -13,4 +13,4 @@ def setup_periodic_tasks(sender, **kwargs):
 
 @app.task(bind=True, name="osism.tasks.kolla.run")
 def run(self, playbook, arguments):
-    run_ansible_in_environment(self.request.id, "kolla", playbook, arguments)
+    return run_ansible_in_environment(self.request.id, "kolla", playbook, arguments)
